package com.ruoyi.baseinfo.service.impl;

import java.util.List;

import com.ruoyi.baseinfo.domain.BasePosttypeInfo;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.baseinfo.mapper.BasePostInfoMapper;
import com.ruoyi.baseinfo.domain.BasePostInfo;
import com.ruoyi.baseinfo.service.IBasePostInfoService;
import com.ruoyi.common.core.text.Convert;

/**
 * 职位基础信息Service业务层处理
 * 
 * @author CaesarBao
 * @date 2020-10-20
 */
@Service
public class BasePostInfoServiceImpl implements IBasePostInfoService 
{
    @Autowired
    private BasePostInfoMapper basePostInfoMapper;

    /**
     * 查询职位基础信息
     * 
     * @param objid 职位基础信息ID
     * @return 职位基础信息
     */
    @Override
    public BasePostInfo selectBasePostInfoById(Long objid)
    {
        return basePostInfoMapper.selectBasePostInfoById(objid);
    }

    /**
     * 查询职位基础信息列表
     * 
     * @param basePostInfo 职位基础信息
     * @return 职位基础信息
     */
    @Override
    public List<BasePostInfo> selectBasePostInfoList(BasePostInfo basePostInfo)
    {
        return basePostInfoMapper.selectBasePostInfoList(basePostInfo);
    }

    /**
     * 新增职位基础信息
     * 
     * @param basePostInfo 职位基础信息
     * @return 结果
     */
    @Override
    public int insertBasePostInfo(BasePostInfo basePostInfo)
    {
        basePostInfo.setCreateTime(DateUtils.getNowDate());
        return basePostInfoMapper.insertBasePostInfo(basePostInfo);
    }

    /**
     * 修改职位基础信息
     * 
     * @param basePostInfo 职位基础信息
     * @return 结果
     */
    @Override
    public int updateBasePostInfo(BasePostInfo basePostInfo)
    {
        basePostInfo.setUpdateTime(DateUtils.getNowDate());
        return basePostInfoMapper.updateBasePostInfo(basePostInfo);
    }

    /**
     * 删除职位基础信息对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteBasePostInfoByIds(String ids)
    {
        return basePostInfoMapper.deleteBasePostInfoByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除职位基础信息信息
     * 
     * @param objid 职位基础信息ID
     * @return 结果
     */
    @Override
    public int deleteBasePostInfoById(Long objid)
    {
        return basePostInfoMapper.deleteBasePostInfoById(objid);
    }

    @Override
    public List<BasePostInfo> selectAddBasePostInfoList()
    {
        return basePostInfoMapper.selectAddBasePostInfoList();
    }

    @Override
    public List<BasePostInfo> selectEditBasePostInfoList(String postId)
    {
        List<BasePostInfo> cbEditPostInfoList = basePostInfoMapper.selectAddBasePostInfoList();
        for (BasePostInfo basePostInfoList:cbEditPostInfoList
             ) {
            if(basePostInfoList.getPostId().equals(postId)){
                basePostInfoList.setFlag(true);
                break;
            }
        }
        return cbEditPostInfoList;
    }
}
